@@ -1,7 +1,7 @@
 package Bencher::Scenario::Exporters::Startup;
 
 our $DATE = '2016-03-13'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,6 +24,7 @@ our $scenario = {
         {module=>'Exporter::Rinci'},
         {module=>'PERLANCAR::Exporter::Lite'},
         {module=>'Sub::Exporter'},
+        {module=>'Xporter'},
     ],
 };
 
@@ -42,7 +43,7 @@ Bencher::Scenario::Exporters::Startup - Benchmark the startup overhead of some e
 
 =head1 VERSION
 
-This document describes version 0.06 of Bencher::Scenario::Exporters::Startup (from Perl distribution Bencher-Scenarios-Exporters), released on 2016-03-13.
+This document describes version 0.07 of Bencher::Scenario::Exporters::Startup (from Perl distribution Bencher-Scenarios-Exporters), released on 2016-03-13.
 
 =head1 SYNOPSIS
 
@@ -70,6 +71,8 @@ L<PERLANCAR::Exporter::Lite> 0.02
 
 L<Sub::Exporter> 0.987
 
+L<Xporter> 0.1.2
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -116,6 +119,12 @@ L<Sub::Exporter>
 
 
 
+=item * Xporter (perl_code)
+
+L<Xporter>
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
@@ -127,14 +136,15 @@ Benchmark with default options (C<< bencher -m Exporters::Startup >>):
  +---------------------------+-----------+------------------------+------------+---------+---------+
  | participant               | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +---------------------------+-----------+------------------------+------------+---------+---------+
- | Sub::Exporter             | 13        | 10.7                   | 1          | 4.9e-05 | 20      |
- | Exporter::Tiny            | 4.9       | 2.6                    | 2.6        | 1.4e-05 | 20      |
- | Exporter::Lite            | 4         | 1.7                    | 3.1        | 1.1e-05 | 20      |
- | Exporter::Rinci           | 3.3       | 1                      | 3.9        | 2.7e-05 | 20      |
- | Exporter                  | 2.8       | 0.5                    | 4.5        | 1.4e-05 | 20      |
- | PERLANCAR::Exporter::Lite | 2.8       | 0.5                    | 4.5        | 2.2e-05 | 20      |
- | Exporter::Tidy            | 2.7       | 0.4                    | 4.6        | 1.1e-05 | 20      |
- | perl -e1 (baseline)       | 2.3       | 0                      | 5.5        | 5.4e-06 | 20      |
+ | Sub::Exporter             | 12        | 9.7                    | 1          | 2.8e-05 | 20      |
+ | Exporter::Tiny            | 5         | 2.7                    | 2.5        | 2.9e-05 | 20      |
+ | Xporter                   | 4.7       | 2.4                    | 2.7        | 1.1e-05 | 20      |
+ | Exporter::Lite            | 4.1       | 1.8                    | 3          | 1.2e-05 | 20      |
+ | Exporter::Rinci           | 3.1       | 0.8                    | 4          | 1.6e-05 | 20      |
+ | Exporter                  | 2.8       | 0.5                    | 4.4        | 9.4e-06 | 20      |
+ | Exporter::Tidy            | 2.7       | 0.4                    | 4.5        | 1.3e-05 | 20      |
+ | PERLANCAR::Exporter::Lite | 2.6       | 0.3                    | 4.7        | 1.5e-05 | 20      |
+ | perl -e1 (baseline)       | 2.3       | 0                      | 5.5        | 2.4e-06 | 20      |
  +---------------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
@@ -161,7 +171,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Sc
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenario-StartupExporters>.
+Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-Exporters>.
 
 =head1 BUGS
 
